@@ -7,13 +7,13 @@ test_that("print method", {
     sim_gen_x() %>%
     sim_gen_v() %>%
     sim_resp_eq(y = 100 + 2 * x + v + e) %>%
-    as.data.frame
+    as.data.frame()
 
   dat$samplingVar <- 1
 
   x <- rfh(y ~ x, dat, "samplingVar", maxIter = 1, maxIterRe = 1)
   # don't know how to test this
-  print(x)
+  testthat::verify_output("./verify-print-rfh-1.out", print(x))
 
   library("saeSim")
   set.seed(3)
@@ -25,7 +25,7 @@ test_that("print method", {
     sim_gen(gen_v_sar(sd = 4, name = "v")) %>%
     sim_gen(gen_v_ar1(rho = 0.5, sd = 4, name = "ar")) %>%
     sim_resp_eq(y = 100 + 2 * x + v + ar + e) %>%
-    as.data.frame
+    as.data.frame()
 
   dat$samplingVar <- rep(16, nrow(dat))
   W <- testRook(nDomains)
@@ -34,8 +34,5 @@ test_that("print method", {
     y ~ x, dat, "samplingVar", corSAR1AR1(W = W, nTime = nTime),
     maxIter = 1, maxIterParam = 1, maxIterRe = 1 # speed up
   )
-  print(out)
-
+  testthat::verify_output("./verify-print-rfh-2.out", print(x))
 })
-
-
